/**
* Copyright (C) 2004-2005 Pantelis Frangoudis, Elias Efstathiou
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

package P2PWNC;

import java.io.IOException;
import java.io.FileOutputStream;
import java.io.FileNotFoundException;

/**
 * This class represents a P2PWNC public or secret key. The algorithm identifier, key data and
 * key data legth is included in in instance of the P2PWNCKey class.
 *
 * @author Pantelis Frangoudis
 * @author Elias Efstathiou
 * @version 0.0.1
 */
class P2PWNCKey extends P2PWNCProto{
        protected int algorithm;
        protected int bits;
        protected int datalen;
        protected byte data[];

        P2PWNCKey() {
                this.algorithm = 0;
                this.bits = 0;
                this.datalen = 0;
        }

        P2PWNCKey(int algorithm, int bits, int datalen) {
                this.algorithm = algorithm;
                this.bits = bits;
                this.datalen = datalen;
                data = new byte[datalen];
        }

        public int getAlgorithm() {
                return this.algorithm;
        }

        public int getBits() {
                return this.bits;
        }

        public int getDatalen() {
                return this.datalen;
        }

        public byte[] getData() {
                return this.data;
        }

        public void setAlgorithm(int algorithm) {
                this.algorithm = algorithm;
        }

        public void setBits(int bits) {
                this.bits = bits;
        }

        public void setData(byte data[]) {
                this.data = data;
        }

        public int keyDataToBinaryFile(String outfile) {
                FileOutputStream fout;
                try {
                 fout = new FileOutputStream(outfile);
                }
                catch (FileNotFoundException e) {
                        System.err.println("keyDataToBinaryFile: Error opening file");
                        return -1;
                }
                try {
                        fout.write(this.data);
                }
                catch (IOException e) {
                        System.err.println("keyDataToBinaryFile: Error decoding file");
                        return -1;
                }

                try {
                        fout.close();
                }
                catch (IOException e) {
                        System.err.println("keyDataToBinaryFile: Error closing output file");
                        return -1;
                }

                return 0;
        }
}
